summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorRobin Watts <robin.watts@artifex.com>2013-06-27 18:24:07 +0100
committerRobin Watts <robin.watts@artifex.com>2013-06-27 20:05:18 +0100
commit9df3a0615a1fa7745160c099e1ac7cd4dfcbc86e (patch)
tree3aac206ddce6e4c50229c9e4e79e3429118035aa /include
parent260e54a956c54058051ce6ff31b36ad0ae1b60aa (diff)
downloadmupdf-9df3a0615a1fa7745160c099e1ac7cd4dfcbc86e.tar.xz
Move to using a flags bit rather than "Dirty" dict entries.
Correct the naming scheme for pdf_obj_xxx functions.
Diffstat (limited to 'include')
-rw-r--r--include/mupdf/pdf/object.h21
1 files changed, 13 insertions, 8 deletions
diff --git a/include/mupdf/pdf/object.h b/include/mupdf/pdf/object.h
index 96b9efd9..ad19779f 100644
--- a/include/mupdf/pdf/object.h
+++ b/include/mupdf/pdf/object.h
@@ -46,14 +46,19 @@ int pdf_objcmp(pdf_obj *a, pdf_obj *b);
/* obj marking and unmarking functions - to avoid infinite recursions. */
int pdf_obj_marked(pdf_obj *obj);
-int pdf_obj_mark(pdf_obj *obj);
-void pdf_obj_unmark(pdf_obj *obj);
-
-/* obj stashing and stash reading functions - allows us to secretly stash
- * a bool in an object, and to read back whether there was a stash, and
- * if so, what it was. */
-void pdf_obj_stash(pdf_obj *obj, int stash);
-int pdf_obj_stashed(pdf_obj *obj, int *stash);
+int pdf_mark_obj(pdf_obj *obj);
+void pdf_unmark_obj(pdf_obj *obj);
+
+/* obj memo functions - allows us to secretly remember "a memo" (a bool) in
+ * an object, and to read back whether there was a memo, and if so, what it
+ * was. */
+void pdf_set_obj_memo(pdf_obj *obj, int memo);
+int pdf_obj_memo(pdf_obj *obj, int *memo);
+
+/* obj dirty bit support. */
+int pdf_obj_is_dirty(pdf_obj *obj);
+void pdf_dirty_obj(pdf_obj *obj);
+void pdf_clean_obj(pdf_obj *obj);
/* safe, silent failure, no error reporting on type mismatches */
int pdf_to_bool(pdf_obj *obj);